@@ -12,14 +12,14 @@ def standardise(
     file_content: bytes | None = None,
 ):
     session_id = uuid.uuid4()
-    schema = load_schema(session_id, schema)
+    _schema = load_schema(session_id, schema)
     loader = Load(
         session_id=session_id,
         file_path=file_path,
         file_name=file_name,
         file_content=file_content,
     )
-    conformer = Conform(session_id=session_id, schema=schema)
+    conformer = Conform(session_id=session_id, schema=_schema)
     # TODO - normaliser, validator
 
     loader.run()
